@@ -20,7 +20,6 @@
 #'
 
 textLabel<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpacing,chrSpacing,markLabelSize,pattern,isCentromeric=FALSE){
-# lapply(1:length(xMark), function(s)
   component<-ifelse(isCentromeric,3,2)
   for (s in 1:length(xMark) ){
     corr_index<-which(names(listOfdfChromSize) %in% names(listOfdfMarkPos)[[s]] )
@@ -40,7 +39,31 @@ textLabel<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpac
       x=xMark[[s]][[m]][1]+chrSpacing2*.1,
       y=( yMark[[s]][[m]][1] + yMark[[s]][[m]][component] ) /2,
       z=sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
-      # t
+      ) #m
+    )# l
+  } # for )# l
+}
+
+textLabelLeft<-function(xMark,yMark,listOfdfChromSize,listOfdfMarkPos,specialChrSpacing,chrSpacing,markLabelSize,pattern,isCentromeric=FALSE){
+  component<-ifelse(isCentromeric,3,2)
+  for (s in 1:length(xMark) ){
+    corr_index<-which(names(listOfdfChromSize) %in% names(listOfdfMarkPos)[[s]] )
+    if(attr(listOfdfChromSize[[corr_index]],"ytitle")=="cM"){
+      chrSpacing2<-specialChrSpacing
+    } else {
+      chrSpacing2<-chrSpacing
+    }
+    lapply(1:length(xMark[[s]]), function (m)
+      mapply(function(x,y,z) graphics::text(x=x,
+                                            y=y,
+                                            label=z,
+                                            cex=markLabelSize,
+                                            # pos=4,
+                                            adj=1 # left
+      ),
+      x=xMark[[s]][[m]][2] - chrSpacing2*.1, # left
+      y=( yMark[[s]][[m]][1] + yMark[[s]][[m]][component] ) /2,
+      z=sub(pattern,"",listOfdfMarkPos[[s]]$markName[m])
       ) #m
     )# l
   } # for )# l
